@@ -1,4 +1,4 @@
-// 	$Id: kdatenav.cpp,v 1.41.2.2 1999/04/16 07:45:15 pbrown Exp $	
+// 	$Id: kdatenav.cpp,v 1.41.2.3 1999/04/30 04:44:35 pbrown Exp $	
 
 #include <qstring.h>
 #include <qtooltip.h>
@@ -436,12 +436,11 @@ inline void KDateNavigator::updateButton(int i)
   if ((buttons[i]->date().year() == QDate::currentDate().year()) &&
       (buttons[i]->date().month() == QDate::currentDate().month()) &&
       (buttons[i]->date().day() == QDate::currentDate().day())) {
-    if (buttons[i]->hiliteStyle() == KDateButton::SelectHilite) {
+    if (buttons[i]->isSelected()) {
       buttons[i]->setHiliteStyle(KDateButton::TodaySelectHilite);
     } else { // it's Today, but not selected
       buttons[i]->setHiliteStyle(KDateButton::TodayHilite);
     }
-    //return;
   }   
 }
 
@@ -592,8 +591,9 @@ void KDateNavigator::fixupSelectedDates(int yr, int mth)
 {
   selectedDates.clear();
   for (int i = 0; i < 42; i++)
-    if (buttons[i]->isSelected())
+    if (buttons[i]->isSelected()) {
       selectedDates.inSort(new QDate(buttons[i]->date()));
+    }
 
   emit datesSelected(selectedDates);
 }
